@@ -142,7 +142,17 @@ static int test_opcode62(AEffect*eff,
 static void test_opcode56(AEffect*eff,
     t_fstInt32 opcode, int index,
     t_fstPtrInt ivalue, void* const ptr, float fvalue) {
+  int i;
+  char*cptr = (char*)ptr;
   print_hex(ptr, 160);
+  snprintf(cptr, 16, "OPCODE56");
+#if 0
+  for(i=0; i<0x99; i++) {
+    cptr[i] = 0;
+  }
+  /* smash the stack */
+  cptr[0x98] = 1;
+#endif
 }
 
 static int test_opcode26(AEffect*eff,
@@ -211,6 +221,9 @@ static bool dispatcher_printEff(AEffect*eff,
 }
 static bool dispatcher_skip(t_fstInt32 opcode) {
   switch(opcode) {
+  case effEditIdle:
+    /* called permanently, if GUI is visible */
+    return true;
   case 53:
     /* REAPER calls this permanently */
     //printf("53...\n");
@@ -226,6 +239,7 @@ static bool dispatcher_noprint(t_fstInt32 opcode) {
   case effGetParamName:
   case effProcessEvents:
   case effVendorSpecific:
+  case effEditIdle:
   case 66:
     return true;
   }
@@ -276,10 +290,10 @@ static t_fstPtrInt dispatcher(AEffect*eff, t_fstInt32 opcode, int index, t_fstPt
     test_opcode42(eff, opcode, index, ivalue, ptr, fvalue);
     return 0;
 #endif
-#if 0
+#if 1
   case 56:
     test_opcode56(eff, opcode, index, ivalue, ptr, fvalue);
-    return 1;
+    return 0;
 #endif
   case effProcessEvents:
     //test_opcode25(eff, opcode, index, ivalue, ptr, fvalue);
