@@ -86,6 +86,7 @@ static char*effCode2string(size_t opcode, char*output, size_t length) {
     FST_UTILS__OPCODESTR(effEditTop);
     FST_UTILS__OPCODESTR(effGetChunk);
     FST_UTILS__OPCODESTR(effGetCurrentMidiProgram);
+    FST_UTILS__OPCODESTR(fst_effGetMidiNoteName);
     FST_UTILS__OPCODESTR(effGetEffectName);
     FST_UTILS__OPCODESTR(effGetInputProperties);
     FST_UTILS__OPCODESTR(effGetNumMidiInputChannels);
@@ -200,6 +201,7 @@ static int effKnown(t_fstPtrInt opcode) {
     case effEditTop:
     case effGetChunk:
     case effGetCurrentMidiProgram:
+    case fst_effGetMidiNoteName:
     case effGetEffectName:
     case effGetInputProperties:
     case effGetNumMidiInputChannels:
